package org.dromara.controller.asset;

import cn.dev33.satoken.annotation.SaCheckPermission;
import jakarta.servlet.http.HttpServletResponse;
import jakarta.validation.constraints.NotEmpty;
import jakarta.validation.constraints.NotNull;
import lombok.RequiredArgsConstructor;
import org.dromara.common.core.domain.R;
import org.dromara.common.core.validate.AddGroup;
import org.dromara.common.core.validate.EditGroup;
import org.dromara.common.excel.utils.ExcelUtil;
import org.dromara.common.idempotent.annotation.RepeatSubmit;
import org.dromara.common.log.annotation.Log;
import org.dromara.common.log.enums.BusinessType;
import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.common.web.core.BaseController;
import org.dromara.domain.asset.bo.AssetTypeBo;
import org.dromara.domain.asset.vo.AssetTypeVo;
import org.dromara.service.IAssetTypeService;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 资产类型
 *
 * @author boman
 * @date 2025-04-11
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/wuYe/assetType")
public class AssetTypeController extends BaseController {

    private final IAssetTypeService assetTypeService;

    /**
     * 查询资产类型列表
     */
    @SaCheckPermission("wuYe:assetType:list")
    @GetMapping("/list")
    public TableDataInfo<AssetTypeVo> list(AssetTypeBo bo, PageQuery pageQuery) {
        return assetTypeService.queryPageList(bo, pageQuery);
    }

    /**
     * 导出资产类型列表
     */
    @SaCheckPermission("wuYe:assetType:export")
    @Log(title = "资产类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(AssetTypeBo bo, HttpServletResponse response) {
        List<AssetTypeVo> list = assetTypeService.queryList(bo);
        ExcelUtil.exportExcel(list, "资产类型", AssetTypeVo.class, response);
    }

    /**
     * 获取资产类型详细信息
     *
     * @param assetId 主键
     */
    @SaCheckPermission("wuYe:assetType:query")
    @GetMapping("/{assetId}")
    public R<AssetTypeVo> getInfo(@NotNull(message = "主键不能为空")
                                     @PathVariable Long assetId) {
        return R.ok(assetTypeService.queryById(assetId));
    }

    /**
     * 新增资产类型
     */
    @SaCheckPermission("wuYe:assetType:add")
    @Log(title = "资产类型", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody AssetTypeBo bo) {
        return toAjax(assetTypeService.insertByBo(bo));
    }

    /**
     * 修改资产类型
     */
    @SaCheckPermission("wuYe:assetType:edit")
    @Log(title = "资产类型", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PostMapping("/put")
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody AssetTypeBo bo) {
        return toAjax(assetTypeService.updateByBo(bo));
    }

    /**
     * 删除资产类型
     *
     * @param assetIds 主键串
     */
    @SaCheckPermission("wuYe:assetType:remove")
    @Log(title = "资产类型", businessType = BusinessType.DELETE)
    @GetMapping("/delete/{assetIds}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable Long[] assetIds) {
        return toAjax(assetTypeService.deleteWithValidByIds(List.of(assetIds), true));
    }
}
