package org.dromara.controller.communityNews;

import cn.dev33.satoken.annotation.SaCheckPermission;
import jakarta.servlet.http.HttpServletResponse;
import jakarta.validation.constraints.NotEmpty;
import jakarta.validation.constraints.NotNull;
import lombok.RequiredArgsConstructor;
import org.dromara.common.core.domain.R;
import org.dromara.common.core.validate.AddGroup;
import org.dromara.common.core.validate.EditGroup;
import org.dromara.common.excel.utils.ExcelUtil;
import org.dromara.common.idempotent.annotation.RepeatSubmit;
import org.dromara.common.log.annotation.Log;
import org.dromara.common.log.enums.BusinessType;
import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.common.web.core.BaseController;
import org.dromara.domain.communityNews.bo.CommentIndexBo;
import org.dromara.domain.communityNews.vo.CommentIndexVo;
import org.dromara.service.ICommentIndexService;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 社区资讯评论
 *
 * @author boman
 * @date 2025-04-11
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/wuYe/commentIndex")
public class CommentIndexController extends BaseController {

    private final ICommentIndexService commentIndexService;

    /**
     * 查询社区资讯评论列表
     */
    @SaCheckPermission("wuYe:commentIndex:list")
    @GetMapping("/list")
    public TableDataInfo<CommentIndexVo> list(CommentIndexBo bo, PageQuery pageQuery) {
        return commentIndexService.queryPageList(bo, pageQuery);
    }

    /**
     * 导出社区资讯评论列表
     */
    @SaCheckPermission("wuYe:commentIndex:export")
    @Log(title = "社区资讯评论", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(CommentIndexBo bo, HttpServletResponse response) {
        List<CommentIndexVo> list = commentIndexService.queryList(bo);
        ExcelUtil.exportExcel(list, "社区资讯评论", CommentIndexVo.class, response);
    }

    /**
     * 获取社区资讯评论详细信息
     *
     * @param commentId 主键
     */
    @SaCheckPermission("wuYe:commentIndex:query")
    @GetMapping("/{commentId}")
    public R<CommentIndexVo> getInfo(@NotNull(message = "主键不能为空")
                                     @PathVariable Long commentId) {
        return R.ok(commentIndexService.queryById(commentId));
    }

    /**
     * 新增社区资讯评论
     */
    @SaCheckPermission("wuYe:commentIndex:add")
    @Log(title = "社区资讯评论", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody CommentIndexBo bo) {
        return toAjax(commentIndexService.insertByBo(bo));
    }

    /**
     * 修改社区资讯评论
     */
    @SaCheckPermission("wuYe:commentIndex:edit")
    @Log(title = "社区资讯评论", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PostMapping("/put")
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody CommentIndexBo bo) {
        return toAjax(commentIndexService.updateByBo(bo));
    }

    /**
     * 删除社区资讯评论
     *
     * @param commentIds 主键串
     */
    @SaCheckPermission("wuYe:commentIndex:remove")
    @Log(title = "社区资讯评论", businessType = BusinessType.DELETE)
    @GetMapping("/delete/{commentIds}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                          @PathVariable Long[] commentIds) {
        return toAjax(commentIndexService.deleteWithValidByIds(List.of(commentIds), true));
    }
}
