package org.dromara.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.RequiredArgsConstructor;
import org.dromara.common.core.utils.MapstructUtils;
import org.dromara.common.core.utils.StringUtils;
import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.asset.AssetType;
import org.dromara.domain.asset.bo.AssetTypeBo;
import org.dromara.domain.asset.vo.AssetTypeVo;
import org.dromara.mapper.AssetTypeMapper;
import org.dromara.service.IAssetTypeService;
import org.springframework.stereotype.Service;

import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * 资产类型Service业务层处理
 *
 * @author boman
 * @date 2025-04-11
 */
@RequiredArgsConstructor
@Service
public class AssetTypeServiceImpl implements IAssetTypeService {

    private final AssetTypeMapper baseMapper;

    /**
     * 查询资产类型
     *
     * @param assetId 主键
     * @return 资产类型
     */
    @Override
    public AssetTypeVo queryById(Long assetId){
        return baseMapper.selectVoById(assetId);
    }

    /**
     * 分页查询资产类型列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 资产类型分页列表
     */
    @Override
    public TableDataInfo<AssetTypeVo> queryPageList(AssetTypeBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<AssetType> lqw = buildQueryWrapper(bo);
        Page<AssetTypeVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询符合条件的资产类型列表
     *
     * @param bo 查询条件
     * @return 资产类型列表
     */
    @Override
    public List<AssetTypeVo> queryList(AssetTypeBo bo) {
        LambdaQueryWrapper<AssetType> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<AssetType> buildQueryWrapper(AssetTypeBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<AssetType> lqw = Wrappers.lambdaQuery();
        lqw.orderByAsc(AssetType::getAssetId);
        lqw.eq(bo.getParentId() != null, AssetType::getParentId, bo.getParentId());
        lqw.eq(StringUtils.isNotBlank(bo.getAncestors()), AssetType::getAncestors, bo.getAncestors());
        lqw.like(StringUtils.isNotBlank(bo.getAssetName()), AssetType::getAssetName, bo.getAssetName());
        lqw.eq(bo.getOrderNum() != null, AssetType::getOrderNum, bo.getOrderNum());
        lqw.eq(StringUtils.isNotBlank(bo.getStatus()), AssetType::getStatus, bo.getStatus());
        return lqw;
    }

    /**
     * 新增资产类型
     *
     * @param bo 资产类型
     * @return 是否新增成功
     */
    @Override
    public Boolean insertByBo(AssetTypeBo bo) {
        AssetType add = MapstructUtils.convert(bo, AssetType.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setAssetId(add.getAssetId());
        }
        return flag;
    }

    /**
     * 修改资产类型
     *
     * @param bo 资产类型
     * @return 是否修改成功
     */
    @Override
    public Boolean updateByBo(AssetTypeBo bo) {
        AssetType update = MapstructUtils.convert(bo, AssetType.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(AssetType entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 校验并批量删除资产类型信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteByIds(ids) > 0;
    }
}
