package org.dromara.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.RequiredArgsConstructor;
import org.dromara.common.core.utils.MapstructUtils;
import org.dromara.common.core.utils.StringUtils;
import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.blackManage.BlackManage;
import org.dromara.domain.blackManage.bo.BlackManageBo;
import org.dromara.domain.blackManage.vo.BlackManageVo;
import org.dromara.mapper.BlackManageMapper;
import org.dromara.service.IBlackManageService;
import org.springframework.stereotype.Service;

import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * 黑名单管理Service业务层处理
 *
 * @author boman
 * @date 2025-04-11
 */
@RequiredArgsConstructor
@Service
public class BlackManageServiceImpl implements IBlackManageService {

    private final BlackManageMapper baseMapper;

    /**
     * 查询黑名单管理
     *
     * @param blackManageId 主键
     * @return 黑名单管理
     */
    @Override
    public BlackManageVo queryById(Long blackManageId){
        return baseMapper.selectVoById(blackManageId);
    }

    /**
     * 分页查询黑名单管理列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 黑名单管理分页列表
     */
    @Override
    public TableDataInfo<BlackManageVo> queryPageList(BlackManageBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<BlackManage> lqw = buildQueryWrapper(bo);
        Page<BlackManageVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询符合条件的黑名单管理列表
     *
     * @param bo 查询条件
     * @return 黑名单管理列表
     */
    @Override
    public List<BlackManageVo> queryList(BlackManageBo bo) {
        LambdaQueryWrapper<BlackManage> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<BlackManage> buildQueryWrapper(BlackManageBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<BlackManage> lqw = Wrappers.lambdaQuery();
        lqw.orderByAsc(BlackManage::getBlackManageId);
        lqw.eq(StringUtils.isNotBlank(bo.getBlackType()), BlackManage::getBlackType, bo.getBlackType());
        lqw.eq(StringUtils.isNotBlank(bo.getBlackTitle()), BlackManage::getBlackTitle, bo.getBlackTitle());
        lqw.eq(StringUtils.isNotBlank(bo.getBlackNum()), BlackManage::getBlackNum, bo.getBlackNum());
        lqw.eq(StringUtils.isNotBlank(bo.getIsDel()), BlackManage::getIsDel, bo.getIsDel());
        return lqw;
    }

    /**
     * 新增黑名单管理
     *
     * @param bo 黑名单管理
     * @return 是否新增成功
     */
    @Override
    public Boolean insertByBo(BlackManageBo bo) {
        BlackManage add = MapstructUtils.convert(bo, BlackManage.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setBlackManageId(add.getBlackManageId());
        }
        return flag;
    }

    /**
     * 修改黑名单管理
     *
     * @param bo 黑名单管理
     * @return 是否修改成功
     */
    @Override
    public Boolean updateByBo(BlackManageBo bo) {
        BlackManage update = MapstructUtils.convert(bo, BlackManage.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(BlackManage entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 校验并批量删除黑名单管理信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteByIds(ids) > 0;
    }
}
