package org.dromara.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.RequiredArgsConstructor;
import org.dromara.common.core.utils.MapstructUtils;
import org.dromara.common.core.utils.StringUtils;
import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.butler.ButlerSettings;
import org.dromara.domain.butler.bo.ButlerSettingsBo;
import org.dromara.domain.butler.vo.ButlerSettingsVo;
import org.dromara.mapper.ButlerSettingsMapper;
import org.dromara.service.IButlerSettingsService;
import org.springframework.stereotype.Service;

import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * 物业管家设置Service业务层处理
 *
 * @author boman
 * @date 2025-04-11
 */
@RequiredArgsConstructor
@Service
public class ButlerSettingsServiceImpl implements IButlerSettingsService {

    private final ButlerSettingsMapper baseMapper;

    /**
     * 查询物业管家设置
     *
     * @param settingsId 主键
     * @return 物业管家设置
     */
    @Override
    public ButlerSettingsVo queryById(Long settingsId){
        return baseMapper.selectVoById(settingsId);
    }

    /**
     * 分页查询物业管家设置列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 物业管家设置分页列表
     */
    @Override
    public TableDataInfo<ButlerSettingsVo> queryPageList(ButlerSettingsBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<ButlerSettings> lqw = buildQueryWrapper(bo);
        Page<ButlerSettingsVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询符合条件的物业管家设置列表
     *
     * @param bo 查询条件
     * @return 物业管家设置列表
     */
    @Override
    public List<ButlerSettingsVo> queryList(ButlerSettingsBo bo) {
        LambdaQueryWrapper<ButlerSettings> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<ButlerSettings> buildQueryWrapper(ButlerSettingsBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<ButlerSettings> lqw = Wrappers.lambdaQuery();
        lqw.orderByAsc(ButlerSettings::getSettingsId);
        lqw.eq(StringUtils.isNotBlank(bo.getTitle()), ButlerSettings::getTitle, bo.getTitle());
        lqw.eq(StringUtils.isNotBlank(bo.getContent()), ButlerSettings::getContent, bo.getContent());
        lqw.eq(StringUtils.isNotBlank(bo.getIsDel()), ButlerSettings::getIsDel, bo.getIsDel());
        return lqw;
    }

    /**
     * 新增物业管家设置
     *
     * @param bo 物业管家设置
     * @return 是否新增成功
     */
    @Override
    public Boolean insertByBo(ButlerSettingsBo bo) {
        ButlerSettings add = MapstructUtils.convert(bo, ButlerSettings.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setSettingsId(add.getSettingsId());
        }
        return flag;
    }

    /**
     * 修改物业管家设置
     *
     * @param bo 物业管家设置
     * @return 是否修改成功
     */
    @Override
    public Boolean updateByBo(ButlerSettingsBo bo) {
        ButlerSettings update = MapstructUtils.convert(bo, ButlerSettings.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(ButlerSettings entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 校验并批量删除物业管家设置信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteByIds(ids) > 0;
    }
}
