package org.dromara.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.RequiredArgsConstructor;
import org.dromara.common.core.utils.MapstructUtils;
import org.dromara.common.core.utils.StringUtils;
import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.communityNews.CommentIndex;
import org.dromara.domain.communityNews.bo.CommentIndexBo;
import org.dromara.domain.communityNews.vo.CommentIndexVo;
import org.dromara.mapper.CommentIndexMapper;
import org.dromara.service.ICommentIndexService;
import org.springframework.stereotype.Service;

import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * 社区资讯评论Service业务层处理
 *
 * @author boman
 * @date 2025-04-11
 */
@RequiredArgsConstructor
@Service
public class CommentIndexServiceImpl implements ICommentIndexService {

    private final CommentIndexMapper baseMapper;

    /**
     * 查询社区资讯评论
     *
     * @param commentId 主键
     * @return 社区资讯评论
     */
    @Override
    public CommentIndexVo queryById(Long commentId){
        return baseMapper.selectVoById(commentId);
    }

    /**
     * 分页查询社区资讯评论列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 社区资讯评论分页列表
     */
    @Override
    public TableDataInfo<CommentIndexVo> queryPageList(CommentIndexBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<CommentIndex> lqw = buildQueryWrapper(bo);
        Page<CommentIndexVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询符合条件的社区资讯评论列表
     *
     * @param bo 查询条件
     * @return 社区资讯评论列表
     */
    @Override
    public List<CommentIndexVo> queryList(CommentIndexBo bo) {
        LambdaQueryWrapper<CommentIndex> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<CommentIndex> buildQueryWrapper(CommentIndexBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<CommentIndex> lqw = Wrappers.lambdaQuery();
        lqw.orderByAsc(CommentIndex::getCommentId);
        lqw.eq(bo.getCommunityId() != null, CommentIndex::getCommunityId, bo.getCommunityId());
        lqw.eq(StringUtils.isNotBlank(bo.getCommunityType()), CommentIndex::getCommunityType, bo.getCommunityType());
        lqw.eq(StringUtils.isNotBlank(bo.getCommunityTitle()), CommentIndex::getCommunityTitle, bo.getCommunityTitle());
        lqw.eq(bo.getIsRoot() != null, CommentIndex::getIsRoot, bo.getIsRoot());
        lqw.eq(bo.getParentId() != null, CommentIndex::getParentId, bo.getParentId());
        lqw.eq(bo.getUserId() != null, CommentIndex::getUserId, bo.getUserId());
        lqw.like(StringUtils.isNotBlank(bo.getNickName()), CommentIndex::getNickName, bo.getNickName());
        lqw.eq(StringUtils.isNotBlank(bo.getAvatar()), CommentIndex::getAvatar, bo.getAvatar());
        lqw.eq(bo.getToUserId() != null, CommentIndex::getToUserId, bo.getToUserId());
        lqw.like(StringUtils.isNotBlank(bo.getToNickName()), CommentIndex::getToNickName, bo.getToNickName());
        lqw.eq(StringUtils.isNotBlank(bo.getToAvatar()), CommentIndex::getToAvatar, bo.getToAvatar());
        lqw.eq(StringUtils.isNotBlank(bo.getToRoot()), CommentIndex::getToRoot, bo.getToRoot());
        lqw.eq(bo.getContentId() != null, CommentIndex::getContentId, bo.getContentId());
        lqw.eq(StringUtils.isNotBlank(bo.getCommentContent()), CommentIndex::getCommentContent, bo.getCommentContent());
        return lqw;
    }

    /**
     * 新增社区资讯评论
     *
     * @param bo 社区资讯评论
     * @return 是否新增成功
     */
    @Override
    public Boolean insertByBo(CommentIndexBo bo) {
        CommentIndex add = MapstructUtils.convert(bo, CommentIndex.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setCommentId(add.getCommentId());
        }
        return flag;
    }

    /**
     * 修改社区资讯评论
     *
     * @param bo 社区资讯评论
     * @return 是否修改成功
     */
    @Override
    public Boolean updateByBo(CommentIndexBo bo) {
        CommentIndex update = MapstructUtils.convert(bo, CommentIndex.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(CommentIndex entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 校验并批量删除社区资讯评论信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteByIds(ids) > 0;
    }
}
