package org.dromara.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.RequiredArgsConstructor;
import org.dromara.common.core.utils.MapstructUtils;
import org.dromara.common.core.utils.StringUtils;
import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.communityNews.CommentLikes;
import org.dromara.domain.communityNews.bo.CommentLikesBo;
import org.dromara.domain.communityNews.vo.CommentLikesVo;
import org.dromara.mapper.CommentLikesMapper;
import org.dromara.service.ICommentLikesService;
import org.springframework.stereotype.Service;

import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * 社区资讯点赞Service业务层处理
 *
 * @author boman
 * @date 2025-04-11
 */
@RequiredArgsConstructor
@Service
public class CommentLikesServiceImpl implements ICommentLikesService {

    private final CommentLikesMapper baseMapper;

    /**
     * 查询社区资讯点赞
     *
     * @param likesId 主键
     * @return 社区资讯点赞
     */
    @Override
    public CommentLikesVo queryById(Long likesId){
        return baseMapper.selectVoById(likesId);
    }

    /**
     * 分页查询社区资讯点赞列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 社区资讯点赞分页列表
     */
    @Override
    public TableDataInfo<CommentLikesVo> queryPageList(CommentLikesBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<CommentLikes> lqw = buildQueryWrapper(bo);
        Page<CommentLikesVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询符合条件的社区资讯点赞列表
     *
     * @param bo 查询条件
     * @return 社区资讯点赞列表
     */
    @Override
    public List<CommentLikesVo> queryList(CommentLikesBo bo) {
        LambdaQueryWrapper<CommentLikes> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<CommentLikes> buildQueryWrapper(CommentLikesBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<CommentLikes> lqw = Wrappers.lambdaQuery();
        lqw.orderByAsc(CommentLikes::getLikesId);
        lqw.eq(bo.getTargetId() != null, CommentLikes::getTargetId, bo.getTargetId());
        lqw.eq(StringUtils.isNotBlank(bo.getTargetType()), CommentLikes::getTargetType, bo.getTargetType());
        lqw.eq(StringUtils.isNotBlank(bo.getTargetTitle()), CommentLikes::getTargetTitle, bo.getTargetTitle());
        lqw.eq(bo.getUserId() != null, CommentLikes::getUserId, bo.getUserId());
        lqw.like(StringUtils.isNotBlank(bo.getNickName()), CommentLikes::getNickName, bo.getNickName());
        lqw.eq(StringUtils.isNotBlank(bo.getAvatar()), CommentLikes::getAvatar, bo.getAvatar());
        return lqw;
    }

    /**
     * 新增社区资讯点赞
     *
     * @param bo 社区资讯点赞
     * @return 是否新增成功
     */
    @Override
    public Boolean insertByBo(CommentLikesBo bo) {
        CommentLikes add = MapstructUtils.convert(bo, CommentLikes.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setLikesId(add.getLikesId());
        }
        return flag;
    }

    /**
     * 修改社区资讯点赞
     *
     * @param bo 社区资讯点赞
     * @return 是否修改成功
     */
    @Override
    public Boolean updateByBo(CommentLikesBo bo) {
        CommentLikes update = MapstructUtils.convert(bo, CommentLikes.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(CommentLikes entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 校验并批量删除社区资讯点赞信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteByIds(ids) > 0;
    }
}
