package org.dromara.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.RequiredArgsConstructor;
import org.dromara.common.core.utils.MapstructUtils;
import org.dromara.common.core.utils.StringUtils;
import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.communityNews.CommentStars;
import org.dromara.domain.communityNews.bo.CommentStarsBo;
import org.dromara.domain.communityNews.vo.CommentStarsVo;
import org.dromara.mapper.CommentStarsMapper;
import org.dromara.service.ICommentStarsService;
import org.springframework.stereotype.Service;

import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * 社区资讯收藏Service业务层处理
 *
 * @author boman
 * @date 2025-04-11
 */
@RequiredArgsConstructor
@Service
public class CommentStarsServiceImpl implements ICommentStarsService {

    private final CommentStarsMapper baseMapper;

    /**
     * 查询社区资讯收藏
     *
     * @param starsId 主键
     * @return 社区资讯收藏
     */
    @Override
    public CommentStarsVo queryById(Long starsId){
        return baseMapper.selectVoById(starsId);
    }

    /**
     * 分页查询社区资讯收藏列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 社区资讯收藏分页列表
     */
    @Override
    public TableDataInfo<CommentStarsVo> queryPageList(CommentStarsBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<CommentStars> lqw = buildQueryWrapper(bo);
        Page<CommentStarsVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询符合条件的社区资讯收藏列表
     *
     * @param bo 查询条件
     * @return 社区资讯收藏列表
     */
    @Override
    public List<CommentStarsVo> queryList(CommentStarsBo bo) {
        LambdaQueryWrapper<CommentStars> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<CommentStars> buildQueryWrapper(CommentStarsBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<CommentStars> lqw = Wrappers.lambdaQuery();
        lqw.orderByAsc(CommentStars::getStarsId);
        lqw.eq(bo.getTargetId() != null, CommentStars::getTargetId, bo.getTargetId());
        lqw.eq(StringUtils.isNotBlank(bo.getTargetType()), CommentStars::getTargetType, bo.getTargetType());
        lqw.eq(StringUtils.isNotBlank(bo.getTargetTitle()), CommentStars::getTargetTitle, bo.getTargetTitle());
        lqw.eq(bo.getUserId() != null, CommentStars::getUserId, bo.getUserId());
        lqw.like(StringUtils.isNotBlank(bo.getNickName()), CommentStars::getNickName, bo.getNickName());
        lqw.eq(StringUtils.isNotBlank(bo.getAvatar()), CommentStars::getAvatar, bo.getAvatar());
        return lqw;
    }

    /**
     * 新增社区资讯收藏
     *
     * @param bo 社区资讯收藏
     * @return 是否新增成功
     */
    @Override
    public Boolean insertByBo(CommentStarsBo bo) {
        CommentStars add = MapstructUtils.convert(bo, CommentStars.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setStarsId(add.getStarsId());
        }
        return flag;
    }

    /**
     * 修改社区资讯收藏
     *
     * @param bo 社区资讯收藏
     * @return 是否修改成功
     */
    @Override
    public Boolean updateByBo(CommentStarsBo bo) {
        CommentStars update = MapstructUtils.convert(bo, CommentStars.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(CommentStars entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 校验并批量删除社区资讯收藏信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteByIds(ids) > 0;
    }
}
