package org.dromara.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.RequiredArgsConstructor;
import org.dromara.common.core.utils.MapstructUtils;
import org.dromara.common.core.utils.StringUtils;
import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.communityNews.CommunityNews;
import org.dromara.domain.communityNews.bo.CommunityNewsBo;
import org.dromara.domain.communityNews.vo.CommunityNewsVo;
import org.dromara.mapper.CommunityNewsMapper;
import org.dromara.service.ICommunityNewsService;
import org.springframework.stereotype.Service;

import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * 社区资讯Service业务层处理
 *
 * @author boman
 * @date 2025-04-11
 */
@RequiredArgsConstructor
@Service
public class CommunityNewsServiceImpl implements ICommunityNewsService {

    private final CommunityNewsMapper baseMapper;

    /**
     * 查询社区资讯
     *
     * @param communityId 主键
     * @return 社区资讯
     */
    @Override
    public CommunityNewsVo queryById(Long communityId){
        return baseMapper.selectVoById(communityId);
    }

    /**
     * 分页查询社区资讯列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 社区资讯分页列表
     */
    @Override
    public TableDataInfo<CommunityNewsVo> queryPageList(CommunityNewsBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<CommunityNews> lqw = buildQueryWrapper(bo);
        Page<CommunityNewsVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询符合条件的社区资讯列表
     *
     * @param bo 查询条件
     * @return 社区资讯列表
     */
    @Override
    public List<CommunityNewsVo> queryList(CommunityNewsBo bo) {
        LambdaQueryWrapper<CommunityNews> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<CommunityNews> buildQueryWrapper(CommunityNewsBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<CommunityNews> lqw = Wrappers.lambdaQuery();
        lqw.orderByAsc(CommunityNews::getCommunityId);
        lqw.eq(StringUtils.isNotBlank(bo.getCommunityTitle()), CommunityNews::getCommunityTitle, bo.getCommunityTitle());
        lqw.eq(StringUtils.isNotBlank(bo.getCommunityType()), CommunityNews::getCommunityType, bo.getCommunityType());
        lqw.eq(StringUtils.isNotBlank(bo.getCommunityContent()), CommunityNews::getCommunityContent, bo.getCommunityContent());
        lqw.eq(StringUtils.isNotBlank(bo.getStatus()), CommunityNews::getStatus, bo.getStatus());
        lqw.eq(bo.getPublishTime() != null, CommunityNews::getPublishTime, bo.getPublishTime());
        lqw.eq(bo.getUserId() != null, CommunityNews::getUserId, bo.getUserId());
        lqw.eq(bo.getStaffId() != null, CommunityNews::getStaffId, bo.getStaffId());
        lqw.like(StringUtils.isNotBlank(bo.getStaffName()), CommunityNews::getStaffName, bo.getStaffName());
        lqw.eq(StringUtils.isNotBlank(bo.getAuthor()), CommunityNews::getAuthor, bo.getAuthor());
        lqw.eq(StringUtils.isNotBlank(bo.getSource()), CommunityNews::getSource, bo.getSource());
        lqw.eq(StringUtils.isNotBlank(bo.getCoverImage()), CommunityNews::getCoverImage, bo.getCoverImage());
        lqw.eq(bo.getViewCount() != null, CommunityNews::getViewCount, bo.getViewCount());
        lqw.eq(StringUtils.isNotBlank(bo.getIsTop()), CommunityNews::getIsTop, bo.getIsTop());
        lqw.eq(StringUtils.isNotBlank(bo.getUserComment()), CommunityNews::getUserComment, bo.getUserComment());
        lqw.eq(StringUtils.isNotBlank(bo.getUserLikes()), CommunityNews::getUserLikes, bo.getUserLikes());
        lqw.eq(StringUtils.isNotBlank(bo.getUserStars()), CommunityNews::getUserStars, bo.getUserStars());
        return lqw;
    }

    /**
     * 新增社区资讯
     *
     * @param bo 社区资讯
     * @return 是否新增成功
     */
    @Override
    public Boolean insertByBo(CommunityNewsBo bo) {
        CommunityNews add = MapstructUtils.convert(bo, CommunityNews.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setCommunityId(add.getCommunityId());
        }
        return flag;
    }

    /**
     * 修改社区资讯
     *
     * @param bo 社区资讯
     * @return 是否修改成功
     */
    @Override
    public Boolean updateByBo(CommunityNewsBo bo) {
        CommunityNews update = MapstructUtils.convert(bo, CommunityNews.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(CommunityNews entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 校验并批量删除社区资讯信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteByIds(ids) > 0;
    }
}
