package org.dromara.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.RequiredArgsConstructor;
import org.dromara.common.core.utils.MapstructUtils;
import org.dromara.common.core.utils.StringUtils;
import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.illegalParking.IllegalParking;
import org.dromara.domain.illegalParking.bo.IllegalParkingBo;
import org.dromara.domain.illegalParking.vo.IllegalParkingVo;
import org.dromara.mapper.IllegalParkingMapper;
import org.dromara.service.IIllegalParkingService;
import org.springframework.stereotype.Service;

import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * 违章停车登记Service业务层处理
 *
 * @author boman
 * @date 2025-04-11
 */
@RequiredArgsConstructor
@Service
public class IllegalParkingServiceImpl implements IIllegalParkingService {

    private final IllegalParkingMapper baseMapper;

    /**
     * 查询违章停车登记
     *
     * @param illegalParkingId 主键
     * @return 违章停车登记
     */
    @Override
    public IllegalParkingVo queryById(Long illegalParkingId){
        return baseMapper.selectVoById(illegalParkingId);
    }

    /**
     * 分页查询违章停车登记列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 违章停车登记分页列表
     */
    @Override
    public TableDataInfo<IllegalParkingVo> queryPageList(IllegalParkingBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<IllegalParking> lqw = buildQueryWrapper(bo);
        Page<IllegalParkingVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询符合条件的违章停车登记列表
     *
     * @param bo 查询条件
     * @return 违章停车登记列表
     */
    @Override
    public List<IllegalParkingVo> queryList(IllegalParkingBo bo) {
        LambdaQueryWrapper<IllegalParking> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<IllegalParking> buildQueryWrapper(IllegalParkingBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<IllegalParking> lqw = Wrappers.lambdaQuery();
        lqw.orderByAsc(IllegalParking::getIllegalParkingId);
        lqw.eq(StringUtils.isNotBlank(bo.getPlateNumber()), IllegalParking::getPlateNumber, bo.getPlateNumber());
        lqw.eq(bo.getPortalId() != null, IllegalParking::getPortalId, bo.getPortalId());
        lqw.eq(StringUtils.isNotBlank(bo.getVisitPortal()), IllegalParking::getVisitPortal, bo.getVisitPortal());
        lqw.eq(StringUtils.isNotBlank(bo.getMobileNumber()), IllegalParking::getMobileNumber, bo.getMobileNumber());
        lqw.like(StringUtils.isNotBlank(bo.getVisitName()), IllegalParking::getVisitName, bo.getVisitName());
        lqw.eq(StringUtils.isNotBlank(bo.getIllegalPhoto()), IllegalParking::getIllegalPhoto, bo.getIllegalPhoto());
        lqw.eq(StringUtils.isNotBlank(bo.getCarType()), IllegalParking::getCarType, bo.getCarType());
        lqw.eq(StringUtils.isNotBlank(bo.getIsBlack()), IllegalParking::getIsBlack, bo.getIsBlack());
        return lqw;
    }

    /**
     * 新增违章停车登记
     *
     * @param bo 违章停车登记
     * @return 是否新增成功
     */
    @Override
    public Boolean insertByBo(IllegalParkingBo bo) {
        IllegalParking add = MapstructUtils.convert(bo, IllegalParking.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setIllegalParkingId(add.getIllegalParkingId());
        }
        return flag;
    }

    /**
     * 修改违章停车登记
     *
     * @param bo 违章停车登记
     * @return 是否修改成功
     */
    @Override
    public Boolean updateByBo(IllegalParkingBo bo) {
        IllegalParking update = MapstructUtils.convert(bo, IllegalParking.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(IllegalParking entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 校验并批量删除违章停车登记信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteByIds(ids) > 0;
    }
}
