package org.dromara.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.RequiredArgsConstructor;
import org.dromara.common.core.utils.MapstructUtils;
import org.dromara.common.core.utils.StringUtils;
import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.houseInfo.PropertySettings;
import org.dromara.domain.houseInfo.bo.PropertySettingsBo;
import org.dromara.domain.houseInfo.vo.PropertySettingsVo;
import org.dromara.mapper.PropertySettingsMapper;
import org.dromara.service.IPropertySettingsService;
import org.springframework.stereotype.Service;

import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * 物业费设置Service业务层处理
 *
 * @author boman
 * @date 2025-04-11
 */
@RequiredArgsConstructor
@Service
public class PropertySettingsServiceImpl implements IPropertySettingsService {

    private final PropertySettingsMapper baseMapper;

    /**
     * 查询物业费设置
     *
     * @param settingsId 主键
     * @return 物业费设置
     */
    @Override
    public PropertySettingsVo queryById(Long settingsId){
        return baseMapper.selectVoById(settingsId);
    }

    /**
     * 分页查询物业费设置列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 物业费设置分页列表
     */
    @Override
    public TableDataInfo<PropertySettingsVo> queryPageList(PropertySettingsBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<PropertySettings> lqw = buildQueryWrapper(bo);
        Page<PropertySettingsVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询符合条件的物业费设置列表
     *
     * @param bo 查询条件
     * @return 物业费设置列表
     */
    @Override
    public List<PropertySettingsVo> queryList(PropertySettingsBo bo) {
        LambdaQueryWrapper<PropertySettings> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<PropertySettings> buildQueryWrapper(PropertySettingsBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<PropertySettings> lqw = Wrappers.lambdaQuery();
        lqw.orderByAsc(PropertySettings::getSettingsId);
        lqw.eq(bo.getTenementExpense() != null, PropertySettings::getTenementExpense, bo.getTenementExpense());
        lqw.eq(bo.getParkingExpense() != null, PropertySettings::getParkingExpense, bo.getParkingExpense());
        lqw.eq(bo.getEnergyExpense() != null, PropertySettings::getEnergyExpense, bo.getEnergyExpense());
        lqw.eq(StringUtils.isNotBlank(bo.getIsDel()), PropertySettings::getIsDel, bo.getIsDel());
        return lqw;
    }

    /**
     * 新增物业费设置
     *
     * @param bo 物业费设置
     * @return 是否新增成功
     */
    @Override
    public Boolean insertByBo(PropertySettingsBo bo) {
        PropertySettings add = MapstructUtils.convert(bo, PropertySettings.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setSettingsId(add.getSettingsId());
        }
        return flag;
    }

    /**
     * 修改物业费设置
     *
     * @param bo 物业费设置
     * @return 是否修改成功
     */
    @Override
    public Boolean updateByBo(PropertySettingsBo bo) {
        PropertySettings update = MapstructUtils.convert(bo, PropertySettings.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(PropertySettings entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 校验并批量删除物业费设置信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteByIds(ids) > 0;
    }
}
