package org.dromara.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.RequiredArgsConstructor;
import org.dromara.common.core.utils.MapstructUtils;
import org.dromara.common.core.utils.StringUtils;
import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.residentInfo.ResidentInfo;
import org.dromara.domain.residentInfo.bo.ResidentInfoBo;
import org.dromara.domain.residentInfo.vo.ResidentInfoVo;
import org.dromara.mapper.ResidentInfoMapper;
import org.dromara.service.IResidentInfoService;
import org.springframework.stereotype.Service;

import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * 居住人员信息，存储居住人员的详细信息Service业务层处理
 *
 * @author boman
 * @date 2025-04-11
 */
@RequiredArgsConstructor
@Service
public class ResidentInfoServiceImpl implements IResidentInfoService {

    private final ResidentInfoMapper baseMapper;

    /**
     * 查询居住人员信息，存储居住人员的详细信息
     *
     * @param residentId 主键
     * @return 居住人员信息，存储居住人员的详细信息
     */
    @Override
    public ResidentInfoVo queryById(Long residentId){
        return baseMapper.selectVoById(residentId);
    }

    /**
     * 分页查询居住人员信息，存储居住人员的详细信息列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 居住人员信息，存储居住人员的详细信息分页列表
     */
    @Override
    public TableDataInfo<ResidentInfoVo> queryPageList(ResidentInfoBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<ResidentInfo> lqw = buildQueryWrapper(bo);
        Page<ResidentInfoVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询符合条件的居住人员信息，存储居住人员的详细信息列表
     *
     * @param bo 查询条件
     * @return 居住人员信息，存储居住人员的详细信息列表
     */
    @Override
    public List<ResidentInfoVo> queryList(ResidentInfoBo bo) {
        LambdaQueryWrapper<ResidentInfo> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<ResidentInfo> buildQueryWrapper(ResidentInfoBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<ResidentInfo> lqw = Wrappers.lambdaQuery();
        lqw.orderByAsc(ResidentInfo::getResidentId);
        lqw.eq(bo.getHouseId() != null, ResidentInfo::getHouseId, bo.getHouseId());
        lqw.eq(bo.getUserId() != null, ResidentInfo::getUserId, bo.getUserId());
        lqw.eq(StringUtils.isNotBlank(bo.getDetailedAddress()), ResidentInfo::getDetailedAddress, bo.getDetailedAddress());
        lqw.like(StringUtils.isNotBlank(bo.getResidentName()), ResidentInfo::getResidentName, bo.getResidentName());
        lqw.eq(StringUtils.isNotBlank(bo.getResidentIdCard()), ResidentInfo::getResidentIdCard, bo.getResidentIdCard());
        lqw.eq(StringUtils.isNotBlank(bo.getResidentBirthday()), ResidentInfo::getResidentBirthday, bo.getResidentBirthday());
        lqw.eq(StringUtils.isNotBlank(bo.getResidentPhone()), ResidentInfo::getResidentPhone, bo.getResidentPhone());
        lqw.eq(bo.getResidentGender() != null, ResidentInfo::getResidentGender, bo.getResidentGender());
        lqw.eq(StringUtils.isNotBlank(bo.getResidentRelationship()), ResidentInfo::getResidentRelationship, bo.getResidentRelationship());
        lqw.eq(StringUtils.isNotBlank(bo.getIsHouseholder()), ResidentInfo::getIsHouseholder, bo.getIsHouseholder());
        lqw.eq(StringUtils.isNotBlank(bo.getIsTenant()), ResidentInfo::getIsTenant, bo.getIsTenant());
        lqw.eq(StringUtils.isNotBlank(bo.getResidentEmployer()), ResidentInfo::getResidentEmployer, bo.getResidentEmployer());
        lqw.eq(StringUtils.isNotBlank(bo.getSpecialType()), ResidentInfo::getSpecialType, bo.getSpecialType());
        lqw.eq(StringUtils.isNotBlank(bo.getResidentHobby()), ResidentInfo::getResidentHobby, bo.getResidentHobby());
        lqw.eq(StringUtils.isNotBlank(bo.getResidentAppearance()), ResidentInfo::getResidentAppearance, bo.getResidentAppearance());
        lqw.eq(StringUtils.isNotBlank(bo.getIdCardFront()), ResidentInfo::getIdCardFront, bo.getIdCardFront());
        lqw.eq(StringUtils.isNotBlank(bo.getIdCardBack()), ResidentInfo::getIdCardBack, bo.getIdCardBack());
        lqw.eq(StringUtils.isNotBlank(bo.getIdCardAddress()), ResidentInfo::getIdCardAddress, bo.getIdCardAddress());
        lqw.eq(StringUtils.isNotBlank(bo.getFacePhoto()), ResidentInfo::getFacePhoto, bo.getFacePhoto());
        return lqw;
    }

    /**
     * 新增居住人员信息，存储居住人员的详细信息
     *
     * @param bo 居住人员信息，存储居住人员的详细信息
     * @return 是否新增成功
     */
    @Override
    public Boolean insertByBo(ResidentInfoBo bo) {
        ResidentInfo add = MapstructUtils.convert(bo, ResidentInfo.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setResidentId(add.getResidentId());
        }
        return flag;
    }

    /**
     * 修改居住人员信息，存储居住人员的详细信息
     *
     * @param bo 居住人员信息，存储居住人员的详细信息
     * @return 是否修改成功
     */
    @Override
    public Boolean updateByBo(ResidentInfoBo bo) {
        ResidentInfo update = MapstructUtils.convert(bo, ResidentInfo.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(ResidentInfo entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 校验并批量删除居住人员信息，存储居住人员的详细信息信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteByIds(ids) > 0;
    }
}
