package org.dromara.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.RequiredArgsConstructor;
import org.dromara.common.core.utils.MapstructUtils;
import org.dromara.common.core.utils.StringUtils;
import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.domain.staffTrain.StaffTrainManual;
import org.dromara.domain.staffTrain.bo.StaffTrainManualBo;
import org.dromara.domain.staffTrain.vo.StaffTrainManualVo;
import org.dromara.mapper.StaffTrainManualMapper;
import org.dromara.service.IStaffTrainManualService;
import org.springframework.stereotype.Service;

import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * 员工培训手册Service业务层处理
 *
 * @author boman
 * @date 2025-04-11
 */
@RequiredArgsConstructor
@Service
public class StaffTrainManualServiceImpl implements IStaffTrainManualService {

    private final StaffTrainManualMapper baseMapper;

    /**
     * 查询员工培训手册
     *
     * @param manualId 主键
     * @return 员工培训手册
     */
    @Override
    public StaffTrainManualVo queryById(Long manualId){
        return baseMapper.selectVoById(manualId);
    }

    /**
     * 分页查询员工培训手册列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 员工培训手册分页列表
     */
    @Override
    public TableDataInfo<StaffTrainManualVo> queryPageList(StaffTrainManualBo bo, PageQuery pageQuery) {
        LambdaQueryWrapper<StaffTrainManual> lqw = buildQueryWrapper(bo);
        Page<StaffTrainManualVo> result = baseMapper.selectVoPage(pageQuery.build(), lqw);
        return TableDataInfo.build(result);
    }

    /**
     * 查询符合条件的员工培训手册列表
     *
     * @param bo 查询条件
     * @return 员工培训手册列表
     */
    @Override
    public List<StaffTrainManualVo> queryList(StaffTrainManualBo bo) {
        LambdaQueryWrapper<StaffTrainManual> lqw = buildQueryWrapper(bo);
        return baseMapper.selectVoList(lqw);
    }

    private LambdaQueryWrapper<StaffTrainManual> buildQueryWrapper(StaffTrainManualBo bo) {
        Map<String, Object> params = bo.getParams();
        LambdaQueryWrapper<StaffTrainManual> lqw = Wrappers.lambdaQuery();
        lqw.orderByAsc(StaffTrainManual::getManualId);
        lqw.eq(StringUtils.isNotBlank(bo.getManualTitle()), StaffTrainManual::getManualTitle, bo.getManualTitle());
        lqw.eq(StringUtils.isNotBlank(bo.getManualType()), StaffTrainManual::getManualType, bo.getManualType());
        lqw.eq(StringUtils.isNotBlank(bo.getManualContent()), StaffTrainManual::getManualContent, bo.getManualContent());
        lqw.eq(StringUtils.isNotBlank(bo.getStatus()), StaffTrainManual::getStatus, bo.getStatus());
        lqw.eq(bo.getPublishTime() != null, StaffTrainManual::getPublishTime, bo.getPublishTime());
        lqw.eq(StringUtils.isNotBlank(bo.getVideoUrl()), StaffTrainManual::getVideoUrl, bo.getVideoUrl());
        lqw.eq(StringUtils.isNotBlank(bo.getCoverImage()), StaffTrainManual::getCoverImage, bo.getCoverImage());
        lqw.eq(StringUtils.isNotBlank(bo.getAuthor()), StaffTrainManual::getAuthor, bo.getAuthor());
        lqw.eq(StringUtils.isNotBlank(bo.getSource()), StaffTrainManual::getSource, bo.getSource());
        lqw.eq(bo.getViewCount() != null, StaffTrainManual::getViewCount, bo.getViewCount());
        lqw.eq(StringUtils.isNotBlank(bo.getProgress()), StaffTrainManual::getProgress, bo.getProgress());
        lqw.eq(StringUtils.isNotBlank(bo.getIsTop()), StaffTrainManual::getIsTop, bo.getIsTop());
        return lqw;
    }

    /**
     * 新增员工培训手册
     *
     * @param bo 员工培训手册
     * @return 是否新增成功
     */
    @Override
    public Boolean insertByBo(StaffTrainManualBo bo) {
        StaffTrainManual add = MapstructUtils.convert(bo, StaffTrainManual.class);
        validEntityBeforeSave(add);
        boolean flag = baseMapper.insert(add) > 0;
        if (flag) {
            bo.setManualId(add.getManualId());
        }
        return flag;
    }

    /**
     * 修改员工培训手册
     *
     * @param bo 员工培训手册
     * @return 是否修改成功
     */
    @Override
    public Boolean updateByBo(StaffTrainManualBo bo) {
        StaffTrainManual update = MapstructUtils.convert(bo, StaffTrainManual.class);
        validEntityBeforeSave(update);
        return baseMapper.updateById(update) > 0;
    }

    /**
     * 保存前的数据校验
     */
    private void validEntityBeforeSave(StaffTrainManual entity){
        //TODO 做一些数据校验,如唯一约束
    }

    /**
     * 校验并批量删除员工培训手册信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    @Override
    public Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return baseMapper.deleteByIds(ids) > 0;
    }
}
